@@ -93,6 +93,7 @@ using std::runtime_error;
 using geos::operation::overlayng::OverlayNG;
 using geos::operation::overlayng::UnaryUnionNG;
 using geos::operation::overlayng::OverlayNGRobust;
+using operation::valid::TopologyValidationError;
 
 namespace {
 
@@ -571,7 +572,7 @@ XMLTester::testValid(const geom::Geometry* g, const std::string& label)
     operation::valid::IsValidOp ivo(g);
     bool valid = ivo.isValid();
     if(! valid) {
-        operation::valid::TopologyValidationError* err = ivo.getValidationError();
+        const TopologyValidationError* err = ivo.getValidationError();
         std::cerr << *curr_file << ":"
                   << " case" << caseCount << ":"
                   << " test" << testCount << ": "
@@ -1290,23 +1291,20 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
         else if(opName == "densify") {
             geom::Geometry* p_gT = gA;
 
-            GeomPtr gRes(parseGeometry(opRes, "expected"));
-            // gRes->normalize();
-
             geom::util::Densifier den(p_gT);
             double distanceTolerance = std::atof(opArg2.c_str());
             den.setDistanceTolerance(distanceTolerance);
             GeomPtr gRealRes = den.getResultGeometry();
+            gRealRes->normalize();
 
-            // gRealRes->normalize();
-
+            GeomPtr gRes(parseGeometry(opRes, "expected"));
+            gRes->normalize();
             if(gRes->compareTo(gRealRes.get()) == 0) {
                 success = 1;
             }
 
             actual_result = printGeom(gRealRes.get());
             expected_result = printGeom(gRes.get());
-
         }
 
 
@@ -1632,13 +1630,6 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
             gRes->normalize();
 
             GeomPtr gRealRes(p_gT->getCentroid());
-
-            if(gRealRes.get()) {
-                gRealRes->normalize();
-            }
-            else {
-                gRealRes = factory->createPoint();
-            }
             gRealRes->normalize();
 
             if(gRes->compareTo(gRealRes.get()) == 0) {
@@ -1719,7 +1710,7 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
 
 
             BufferOp op(p_gT, params);
-            gRealRes.reset(op.getResultGeometry(dist));
+            gRealRes = op.getResultGeometry(dist);
 
             profile.stop();
             gRealRes->normalize();
@@ -1763,8 +1754,7 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
             }
 
             BufferBuilder bufBuilder(params) ;
-            gRealRes.reset(bufBuilder.bufferLineSingleSided(
-                               p_gT, dist, leftSide)) ;
+            gRealRes = bufBuilder.bufferLineSingleSided(p_gT, dist, leftSide);
 
             profile.stop();
             gRealRes->normalize();
@@ -1805,7 +1795,7 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
             }
 
             BufferOp op(p_gT, params);
-            gRealRes.reset(op.getResultGeometry(dist));
+            gRealRes = op.getResultGeometry(dist);
 
             profile.stop();
             gRealRes->normalize();
@@ -2218,10 +2208,16 @@ XMLTester::parseTest(const tinyxml2::XMLNode* node)
 
     }
     catch(const std::exception& e) {
-        std::cerr << "EXCEPTION on case " << caseCount
-                  << " test " << testCount << ": " << e.what()
-                  << std::endl;
-        actual_result = e.what();
+        if (expected_result == "exception") {
+            success = true;
+            actual_result = "exception";
+        }
+        else {
+            std::cerr << "EXCEPTION on case " << caseCount
+                      << " test " << testCount << ": " << e.what()
+                      << std::endl;
+            actual_result = e.what();
+        }
     }
     catch(...) {
         std::cerr << "Unknown EXEPTION on case "
